BlocEvent class abstract

BlocEvent is an abstract class that all events of a Bloc must extend. Events in the Bloc pattern represent actions that trigger state changes.

Constructors

BlocEvent()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited