getBloc method
Method to retrieve a Bloc instance from the widget context. The context.read
Implementation
BL getBloc(BuildContext context) {
return context.read<BL>();
}
Method to retrieve a Bloc instance from the widget context. The context.read
BL getBloc(BuildContext context) {
return context.read<BL>();
}