builder property
A builder function that constructs the widget tree using the provided ScopeController.
Implementation
final Widget Function(BuildContext context, T controller) builder;
A builder function that constructs the widget tree using the provided ScopeController.
final Widget Function(BuildContext context, T controller) builder;