onBuild abstract method
Abstract method for building the widget's UI. It will be wrapped inside a BlocListener and BlocBuilder to react to state changes and rebuild the UI.
Implementation
@protected
Widget onBuild(final BuildContext context);
Abstract method for building the widget's UI. It will be wrapped inside a BlocListener and BlocBuilder to react to state changes and rebuild the UI.
@protected
Widget onBuild(final BuildContext context);