ScopeController<BL extends Bloc<BlocEvent, BlocState> > class
abstract
ScopeController is an abstract class that serves as a controller for a Bloc (a pattern that separates business logic from UI). It provides a way to create or retrieve a Bloc instance.
All controllers should extend this class.
Constructors
Properties
- context ↔ BuildContext
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createBloc(
BuildContext context) → BL - Abstract getter that requires subclasses to provide a way to create a Bloc instance.
-
getBloc(
BuildContext context) → BL - Method to retrieve a Bloc instance from the widget context. The context.read
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited